<TS language="pl_PL" version="2.1">
<context>
    <name>AddressBookPage</name>
    <message>
        <source>Right-click to edit address or label</source>
        <translation>Kliknij prawy przycisk myszy, aby edytować adres lub etykietę</translation>
    </message>
    <message>
        <source>Create a new address</source>
        <translation>Utwórz nowy adres</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;Nowy</translation>
    </message>
    <message>
        <source>Copy the currently selected address to the system clipboard</source>
        <translation>Skopiuj aktualnie wybrany adres do schowka</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation>&amp;Kopiuj</translation>
    </message>
    <message>
        <source>C&amp;lose</source>
        <translation>Z&amp;amknij</translation>
    </message>
    <message>
        <source>Delete the currently selected address from the list</source>
        <translation>Usuń zaznaczony adres z listy</translation>
    </message>
    <message>
        <source>Enter address or label to search</source>
        <translation>Wpisz adres lub etykiete zeby wyszukac</translation>
    </message>
    <message>
        <source>Export the data in the current tab to a file</source>
        <translation>Eksportuj dane z aktywnej karty do pliku</translation>
    </message>
    <message>
        <source>&amp;Export</source>
        <translation>&amp;Eksportuj</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>&amp;Usuń</translation>
    </message>
    <message>
        <source>Choose the address to send coins to</source>
        <translation>Wybierz adres do wysłania monet</translation>
    </message>
    <message>
        <source>Choose the address to receive coins with</source>
        <translation>Wybierz adres, na który chcesz otrzymać monety</translation>
    </message>
    <message>
        <source>C&amp;hoose</source>
        <translation>&amp;Wybierz</translation>
    </message>
    <message>
        <source>Sending addresses</source>
        <translation>Adresy do wysyłania</translation>
    </message>
    <message>
        <source>Receiving addresses</source>
        <translation>Adresy do odbierania</translation>
    </message>
    <message>
        <source>These are your Litecoin addresses for sending payments. Always check the amount and the receiving address before sending coins.</source>
        <translation>To są Twoje adresy Litecoin do wysyłania płatności. Zawsze sprawdzaj kwotę oraz adres odbioru zanim prześlesz monety.</translation>
    </message>
    <message>
        <source>These are your Litecoin addresses for receiving payments. It is recommended to use a new receiving address for each transaction.</source>
        <translation>To są Twoje adresy Litecoin do otrzymywania płatności. Zalecane jest używać nowego adresu do każdej transakcji. </translation>
    </message>
    <message>
        <source>&amp;Copy Address</source>
        <translation>&amp;Kopiuj Adres</translation>
    </message>
    <message>
        <source>Copy &amp;Label</source>
        <translation>Kopiuj &amp;Etykietę</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>&amp;Edytuj</translation>
    </message>
    <message>
        <source>Export Address List</source>
        <translation>Eksportuj listę adresów</translation>
    </message>
    <message>
        <source>Comma separated file (*.csv)</source>
        <translation>Plik oddzielony przecinkiem (*.csv)</translation>
    </message>
    <message>
        <source>Exporting Failed</source>
        <translation>Eksport nie powiódł się</translation>
    </message>
    <message>
        <source>There was an error trying to save the address list to %1. Please try again.</source>
        <translation>Wystąpił błąd podczas zapisywania listy adresów do %1. Proszę spróbować ponownie.</translation>
    </message>
</context>
<context>
    <name>AddressTableModel</name>
    <message>
        <source>Label</source>
        <translation>Etykieta</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Adres</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(bez etykiety)</translation>
    </message>
</context>
<context>
    <name>AskPassphraseDialog</name>
    <message>
        <source>Passphrase Dialog</source>
        <translation>Okno dialogowe hasła</translation>
    </message>
    <message>
        <source>Enter passphrase</source>
        <translation>Wprowadź passphrase</translation>
    </message>
    <message>
        <source>New passphrase</source>
        <translation>Nowe hasło</translation>
    </message>
    <message>
        <source>Repeat new passphrase</source>
        <translation>Wprowadź ponownie hasło</translation>
    </message>
    <message>
        <source>Show password</source>
        <translation>Pokaz haslo</translation>
    </message>
    <message>
        <source>Enter the new passphrase to the wallet.&lt;br/&gt;Please use a passphrase of &lt;b&gt;ten or more random characters&lt;/b&gt;, or &lt;b&gt;eight or more words&lt;/b&gt;.</source>
        <translation>Wpisz nowe hasło do portfela. Proszę użyć hasła składającego się z 10 lub więcej różnych znaków albo ośmiu lub więcej słów. </translation>
    </message>
    <message>
        <source>Encrypt wallet</source>
        <translation>Zaszyfruj portfel</translation>
    </message>
    <message>
        <source>This operation needs your wallet passphrase to unlock the wallet.</source>
        <translation>Ta operacja wymaga Twojego hasła do portfela by odblokować portfel.</translation>
    </message>
    <message>
        <source>Unlock wallet</source>
        <translation>Odblokować portfel</translation>
    </message>
    <message>
        <source>This operation needs your wallet passphrase to decrypt the wallet.</source>
        <translation>Ta operacja wymaga Twojego hasła do portfela by odszyfrować portfel.</translation>
    </message>
    <message>
        <source>Decrypt wallet</source>
        <translation>Odszyfruj portfel</translation>
    </message>
    <message>
        <source>Change passphrase</source>
        <translation>Zmień hasło</translation>
    </message>
    <message>
        <source>Enter the old passphrase and new passphrase to the wallet.</source>
        <translation>Wpisz stare a następnie nowe hasło do portfela.</translation>
    </message>
    <message>
        <source>Confirm wallet encryption</source>
        <translation>Potwierdź zaszyfrowanie portfela.</translation>
    </message>
    <message>
        <source>Warning: If you encrypt your wallet and lose your passphrase, you will &lt;b&gt;LOSE ALL OF YOUR LITECOINS&lt;/b&gt;!</source>
        <translation>Uwaga: Jeśli zaszyfrujesz portfel i utracisz do niego hasło, stracisz wszystkie swoje Litecoiny. </translation>
    </message>
    <message>
        <source>Are you sure you wish to encrypt your wallet?</source>
        <translation>Czy na pewno chcesz zaszyfrować portfel?</translation>
    </message>
    <message>
        <source>Wallet encrypted</source>
        <translation>Portfel zaszyfrowany</translation>
    </message>
    <message>
        <source>IMPORTANT: Any previous backups you have made of your wallet file should be replaced with the newly generated, encrypted wallet file. For security reasons, previous backups of the unencrypted wallet file will become useless as soon as you start using the new, encrypted wallet.</source>
        <translation>WAŻNE: Wszystkie wcześniejsze kopie zapasowe jakie stworzyłeś powinny być zastąpione świeżo wygenerowanymi, zaszyfrowanymi plikami portfela. Dla bezpieczeństwa, wcześniejsze kopie niezaszyfrowanego portfela będą nieużyteczne jak tylko zaczniesz używać nowego zaszyfrowanego portfela. </translation>
    </message>
    <message>
        <source>Wallet encryption failed</source>
        <translation>Szyfrowanie portfela się nie powiodło</translation>
    </message>
    <message>
        <source>Wallet encryption failed due to an internal error. Your wallet was not encrypted.</source>
        <translation>Szyfrowanie portfela się nie powiodło z powodu wewnętrznego błędu. Twój portfel nie został zaszyfrowany.</translation>
    </message>
    <message>
        <source>The supplied passphrases do not match.</source>
        <translation>Wpisane hasło nie pasuje. </translation>
    </message>
    <message>
        <source>Wallet unlock failed</source>
        <translation>Odblokowanie portfela nie powiodło się.</translation>
    </message>
    <message>
        <source>The passphrase entered for the wallet decryption was incorrect.</source>
        <translation>Hasło wprowadzone by odkodować portfel jest niepoprawne.</translation>
    </message>
    <message>
        <source>Wallet decryption failed</source>
        <translation>Odszyfrowanie portfela nie powiodło się.</translation>
    </message>
    <message>
        <source>Wallet passphrase was successfully changed.</source>
        <translation>Hasło do portfela zostało prawidłowo zmienione.</translation>
    </message>
    <message>
        <source>Warning: The Caps Lock key is on!</source>
        <translation>Uwaga, masz włączonego CAPSlocka!</translation>
    </message>
</context>
<context>
    <name>BanTableModel</name>
    <message>
        <source>IP/Netmask</source>
        <translation>IP/Maska sieci</translation>
    </message>
    <message>
        <source>Banned Until</source>
        <translation>Zablokowany do</translation>
    </message>
</context>
<context>
    <name>BitcoinGUI</name>
    <message>
        <source>Sign &amp;message...</source>
        <translation>Stopka</translation>
    </message>
    <message>
        <source>Synchronizing with network...</source>
        <translation>Synchronizuję się z siecią</translation>
    </message>
    <message>
        <source>&amp;Overview</source>
        <translation>&amp;Przegląd</translation>
    </message>
    <message>
        <source>Show general overview of wallet</source>
        <translation>Pokaż podsumowanie portfela</translation>
    </message>
    <message>
        <source>&amp;Transactions</source>
        <translation>&amp;Transakcje</translation>
    </message>
    <message>
        <source>Browse transaction history</source>
        <translation>Przeglądaj historię transakcji</translation>
    </message>
    <message>
        <source>E&amp;xit</source>
        <translation>W&amp;yjście</translation>
    </message>
    <message>
        <source>Quit application</source>
        <translation>Opuść aplikację</translation>
    </message>
    <message>
        <source>&amp;About %1</source>
        <translation>&amp;O aplikacji %1</translation>
    </message>
    <message>
        <source>Show information about %1</source>
        <translation>Pokaż szczegóły o %1</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>O aplikacji &amp;Qt</translation>
    </message>
    <message>
        <source>Show information about Qt</source>
        <translation>Pokaż informacje na temat Qt</translation>
    </message>
    <message>
        <source>&amp;Options...</source>
        <translation>&amp;Opcje...</translation>
    </message>
    <message>
        <source>Modify configuration options for %1</source>
        <translation>Zmodyfikuj opcje konfiguracji dla %1</translation>
    </message>
    <message>
        <source>&amp;Encrypt Wallet...</source>
        <translation>&amp;Zaszyfruj Portfel...</translation>
    </message>
    <message>
        <source>&amp;Backup Wallet...</source>
        <translation>&amp;Utwórz kopię zapasową portfela...</translation>
    </message>
    <message>
        <source>&amp;Change Passphrase...</source>
        <translation>&amp;Zmień Hasło...</translation>
    </message>
    <message>
        <source>Open &amp;URI...</source>
        <translation>Otwórz &amp;URl...</translation>
    </message>
    <message>
        <source>Click to disable network activity.</source>
        <translation>Kliknij żeby zablokować aktywność sieciową.</translation>
    </message>
    <message>
        <source>Network activity disabled.</source>
        <translation>Aktywność sieciowa zablokowana.</translation>
    </message>
    <message>
        <source>Click to enable network activity again.</source>
        <translation>Kliknij żeby aktywować aktywność sieciową ponownie.</translation>
    </message>
    <message>
        <source>Syncing Headers (%1%)...</source>
        <translation>Synchronizowanie nagłówków (%1%)...</translation>
    </message>
    <message>
        <source>Reindexing blocks on disk...</source>
        <translation>Reindeksowanie bloków na dysku...</translation>
    </message>
    <message>
        <source>Send coins to a Litecoin address</source>
        <translation>Wyślij monety na adres Litecoin</translation>
    </message>
    <message>
        <source>Backup wallet to another location</source>
        <translation>Utwórz kopię zapasową portfela w innej lokalizacji</translation>
    </message>
    <message>
        <source>Change the passphrase used for wallet encryption</source>
        <translation>Zmień hasło wykorzystywane do szyfrowania portfela</translation>
    </message>
    <message>
        <source>&amp;Debug window</source>
        <translation>&amp;Okno debugowania</translation>
    </message>
    <message>
        <source>Open debugging and diagnostic console</source>
        <translation>Otwórz konsole diagnostyki i debugowania</translation>
    </message>
    <message>
        <source>&amp;Verify message...</source>
        <translation>&amp;Zweryfikuj wiadomość...</translation>
    </message>
    <message>
        <source>Litecoin</source>
        <translation>Litecoin</translation>
    </message>
    <message>
        <source>&amp;Send</source>
        <translation>&amp;Wyślij</translation>
    </message>
    <message>
        <source>&amp;Receive</source>
        <translation>&amp;Odbierz</translation>
    </message>
    <message>
        <source>&amp;Show / Hide</source>
        <translation>&amp;Pokaż / Ukryj</translation>
    </message>
    <message>
        <source>Show or hide the main Window</source>
        <translation>Ukryj lub pokaż główne okno</translation>
    </message>
    <message>
        <source>Encrypt the private keys that belong to your wallet</source>
        <translation>Zaszyfruj prywatne klucze które należą do Twojego portfela</translation>
    </message>
    <message>
        <source>Sign messages with your Litecoin addresses to prove you own them</source>
        <translation>Podpisz wiadomość z Twoimi adresami Litecoin żeby udowodnić że je posiadasz</translation>
    </message>
    <message>
        <source>Verify messages to ensure they were signed with specified Litecoin addresses</source>
        <translation>Zweryfikuj wiadomość żeby się upewnić że zostały podpisane ze specyficznym adresem Litecoin</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Plik</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Ustawienia</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Pomoc</translation>
    </message>
    <message>
        <source>Tabs toolbar</source>
        <translation>Pasek zakładek</translation>
    </message>
    <message>
        <source>Request payments (generates QR codes and litecoin: URIs)</source>
        <translation>Zażądaj płatności (generuje kod QR oraz litecoin: URls)</translation>
    </message>
    <message>
        <source>Show the list of used sending addresses and labels</source>
        <translation>Pokaż liste użytych adresów do wysyłania oraz ich etykiety</translation>
    </message>
    <message>
        <source>Show the list of used receiving addresses and labels</source>
        <translation>Pokaż liste użytych adresów do odbioru oraz ich etykiety</translation>
    </message>
    <message>
        <source>Open a litecoin: URI or payment request</source>
        <translation>Otwórz litecoin: URl lub żądanie płatności</translation>
    </message>
    <message>
        <source>&amp;Command-line options</source>
        <translation>&amp;Wiersz-poleceń opcje</translation>
    </message>
    <message>
        <source>Indexing blocks on disk...</source>
        <translation>Indeksowanie bloków na dysku...</translation>
    </message>
    <message>
        <source>Processing blocks on disk...</source>
        <translation>Przetwarzanie bloków na dysku...</translation>
    </message>
    <message>
        <source>%1 behind</source>
        <translation>%1 za</translation>
    </message>
    <message>
        <source>Last received block was generated %1 ago.</source>
        <translation>Ostatni otrzymany blok został wygenerowany %1 temu.</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Błąd</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>Ostrzeżenie</translation>
    </message>
    <message>
        <source>Information</source>
        <translation>Informacja</translation>
    </message>
    <message>
        <source>%1 client</source>
        <translation>%1 klient</translation>
    </message>
    <message>
        <source>Date: %1
</source>
        <translation>Data: %1
</translation>
    </message>
    <message>
        <source>Amount: %1
</source>
        <translation>Ilość: %1
</translation>
    </message>
    <message>
        <source>Type: %1
</source>
        <translation>Typ: %1
</translation>
    </message>
    <message>
        <source>Address: %1
</source>
        <translation>Adres: %1
</translation>
    </message>
    <message>
        <source>Incoming transaction</source>
        <translation>Transakcja przychodząca.</translation>
    </message>
    </context>
<context>
    <name>CoinControlDialog</name>
    <message>
        <source>Quantity:</source>
        <translation>Ilość:</translation>
    </message>
    <message>
        <source>Bytes:</source>
        <translation>Bajtów:</translation>
    </message>
    <message>
        <source>Amount:</source>
        <translation>Ilość:</translation>
    </message>
    <message>
        <source>Fee:</source>
        <translation>Opłata:</translation>
    </message>
    <message>
        <source>After Fee:</source>
        <translation>Po odliczeniu opłaty:</translation>
    </message>
    <message>
        <source>Change:</source>
        <translation>Zmiana:</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>Ilość</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Data</translation>
    </message>
    <message>
        <source>Copy address</source>
        <translation>Kopiuj adres</translation>
    </message>
    <message>
        <source>Copy label</source>
        <translation>Kopiuj etykietę</translation>
    </message>
    <message>
        <source>Copy amount</source>
        <translation>Kopiuj ilość</translation>
    </message>
    <message>
        <source>Copy quantity</source>
        <translation>Kopiuj ilość</translation>
    </message>
    <message>
        <source>Copy fee</source>
        <translation>Kopiuj koszt</translation>
    </message>
    <message>
        <source>Copy after fee</source>
        <translation>Kopiuj po opłacie</translation>
    </message>
    <message>
        <source>Copy bytes</source>
        <translation>Kopiuj bajty</translation>
    </message>
    <message>
        <source>Copy dust</source>
        <translation>Kopiuj pył</translation>
    </message>
    <message>
        <source>Copy change</source>
        <translation>Kopiuj zmianę</translation>
    </message>
    <message>
        <source>yes</source>
        <translation>tak</translation>
    </message>
    <message>
        <source>no</source>
        <translation>nie</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(bez etykiety)</translation>
    </message>
    </context>
<context>
    <name>EditAddressDialog</name>
    <message>
        <source>&amp;Label</source>
        <translation>&amp;Etykieta</translation>
    </message>
    </context>
<context>
    <name>FreespaceChecker</name>
    </context>
<context>
    <name>HelpMessageDialog</name>
    </context>
<context>
    <name>Intro</name>
    <message>
        <source>Welcome</source>
        <translation>Witaj!</translation>
    </message>
    <message>
        <source>Welcome to %1.</source>
        <translation>Witaj w %1.</translation>
    </message>
    <message>
        <source>As this is the first time the program is launched, you can choose where %1 will store its data.</source>
        <translation>Ponieważ to Twoje pierwsze użycie programu, możesz wybrać gdzie %1 będzie przechowywać swoje dane.</translation>
    </message>
    <message>
        <source>When you click OK, %1 will begin to download and process the full %4 block chain (%2GB) starting with the earliest transactions in %3 when %4 initially launched.</source>
        <translation>Kiedy klikniesz OK, %1 zacznie proces ściągania i przetwarzania pełnego łańcuchu bloków (%2GB) zaczynając od najwcześniejszych transakcji w %3 kiedy %4 wstępnie się uruchomi.</translation>
    </message>
    <message>
        <source>This initial synchronisation is very demanding, and may expose hardware problems with your computer that had previously gone unnoticed. Each time you run %1, it will continue downloading where it left off.</source>
        <translation>Wstępna synchronizacja jest dość wymagająca i może odsłonić pewne problemy z komputerem które wcześniej nie zostały zauważone. Za każdym razem jak uruchomisz %1, będzie kontynuować ściąganie tam gdzie się wcześniej skończyło.</translation>
    </message>
    <message>
        <source>If you have chosen to limit block chain storage (pruning), the historical data must still be downloaded and processed, but will be deleted afterward to keep your disk usage low.</source>
        <translation>Jeśli wybrałeś opcje ograniczenia rozmiaru łańcucha bloków (przycinanie), to historyczne dane muszą najpierw zostać ściągnięte i przetworzone, ale zostaną potem skasowane żeby zaoszczędzić miejsce na dysku.</translation>
    </message>
    <message>
        <source>Use the default data directory</source>
        <translation>Użyj domyślnego katalogu danych</translation>
    </message>
    <message>
        <source>Use a custom data directory:</source>
        <translation>Użyj wybranego katalogu danych:</translation>
    </message>
    <message>
        <source>Litecoin</source>
        <translation>Litecoin</translation>
    </message>
    <message>
        <source>At least %1 GB of data will be stored in this directory, and it will grow over time.</source>
        <translation>Przynajmniej %1 GB danych będzie przechowywane w następującym katalogu danych i będzie z czasem rosnąć.</translation>
    </message>
    <message>
        <source>Approximately %1 GB of data will be stored in this directory.</source>
        <translation>W przybliżeniu %1 GB danych będzie przechowywanych w tym katalogu. </translation>
    </message>
    <message>
        <source>%1 will download and store a copy of the Litecoin block chain.</source>
        <translation>%1 ściągnie i przechowa kopie łańcucha bloków Litecoin.</translation>
    </message>
    <message>
        <source>The wallet will also be stored in this directory.</source>
        <translation>Portfel również będzie przechowywany w tym katalogu.</translation>
    </message>
    <message>
        <source>Error: Specified data directory "%1" cannot be created.</source>
        <translation>Błąd: Określony katalog danych "%1" nie może zostać stworzony.</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Błąd</translation>
    </message>
    </context>
<context>
    <name>ModalOverlay</name>
    <message>
        <source>Form</source>
        <translation>Formularz</translation>
    </message>
    <message>
        <source>Recent transactions may not yet be visible, and therefore your wallet's balance might be incorrect. This information will be correct once your wallet has finished synchronizing with the litecoin network, as detailed below.</source>
        <translation>Niedawne transakcje mogą być jeszcze nie widoczne i z tego powodu saldo Twojego portfela może być nieprawidłowe. Te informacje zostaną poprawione kiedy Twój portfel skończy się synchronizować z siecią Litecoin, w sposób opisany poniżej. </translation>
    </message>
    <message>
        <source>Attempting to spend litecoins that are affected by not-yet-displayed transactions will not be accepted by the network.</source>
        <translation>Próby przesłania Litecoinów które nie zostały jeszcze wyświetlone w transakcjach nie zostaną zaakceptowane przez sieć.</translation>
    </message>
    <message>
        <source>Number of blocks left</source>
        <translation>Pozostały numer bloków</translation>
    </message>
    <message>
        <source>Unknown...</source>
        <translation>Nieznany...</translation>
    </message>
    <message>
        <source>Last block time</source>
        <translation>Czas ostatniego bloku...</translation>
    </message>
    <message>
        <source>Progress</source>
        <translation>Postęp</translation>
    </message>
    <message>
        <source>Progress increase per hour</source>
        <translation>Wzrost postępu na godzinę</translation>
    </message>
    <message>
        <source>calculating...</source>
        <translation>obliczanie...</translation>
    </message>
    <message>
        <source>Estimated time left until synced</source>
        <translation>Szacowany pozostały czas do skończenia synchronizacji</translation>
    </message>
    <message>
        <source>Hide</source>
        <translation>Ukryj</translation>
    </message>
    </context>
<context>
    <name>OpenURIDialog</name>
    <message>
        <source>Open URI</source>
        <translation>Otwórz URl</translation>
    </message>
    <message>
        <source>Open payment request from URI or file</source>
        <translation>Otwórz żądanie płatności z URl lub pliku</translation>
    </message>
    <message>
        <source>URI:</source>
        <translation>URl:</translation>
    </message>
    <message>
        <source>Select payment request file</source>
        <translation>Otwórz plik z żądaniem płatności</translation>
    </message>
    <message>
        <source>Select payment request file to open</source>
        <translation>Wybierz plik do otwarcia z żądaniem płatności </translation>
    </message>
</context>
<context>
    <name>OptionsDialog</name>
    <message>
        <source>Options</source>
        <translation>Opcje</translation>
    </message>
    <message>
        <source>&amp;Main</source>
        <translation>&amp;Główny</translation>
    </message>
    <message>
        <source>Automatically start %1 after logging in to the system.</source>
        <translation>Automatycznie zacznij %1 po zalogowaniu do systemu.</translation>
    </message>
    <message>
        <source>&amp;Start %1 on system login</source>
        <translation>&amp;Zacznij %1 podczas logowania do systemu</translation>
    </message>
    <message>
        <source>Number of script &amp;verification threads</source>
        <translation>Numer skryptów &amp; wątków weryfikacji</translation>
    </message>
    <message>
        <source>Confirm options reset</source>
        <translation>Potwierdź opcje resetu.</translation>
    </message>
    <message>
        <source>Client restart required to activate changes.</source>
        <translation>Program wymaga ponownego uruchomienia by zapisać zmiany.</translation>
    </message>
    <message>
        <source>Client will be shut down. Do you want to proceed?</source>
        <translation>Program zostanie zamknięty. Czy chcesz kontynuować?</translation>
    </message>
    <message>
        <source>Configuration options</source>
        <translation>Opcje konfiguracji.</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Błąd</translation>
    </message>
    <message>
        <source>The configuration file could not be opened.</source>
        <translation>Plik konfiguracji nie mógł zostać otwarty poprawnie.</translation>
    </message>
    <message>
        <source>This change would require a client restart.</source>
        <translation>Aby zapisać zmianę należy ponownie uruchomić program.</translation>
    </message>
    <message>
        <source>The supplied proxy address is invalid.</source>
        <translation>Wprowadzony adres proxy jest nieprawidłowy.</translation>
    </message>
</context>
<context>
    <name>OverviewPage</name>
    <message>
        <source>Form</source>
        <translation>Formularz</translation>
    </message>
    <message>
        <source>Watch-only:</source>
        <translation>Tylko do odczytu:</translation>
    </message>
    <message>
        <source>Available:</source>
        <translation>Dostępne:</translation>
    </message>
    <message>
        <source>Your current spendable balance</source>
        <translation>Twoje obecne środki do wydania</translation>
    </message>
    <message>
        <source>Pending:</source>
        <translation>W trakcie:</translation>
    </message>
    <message>
        <source>Immature:</source>
        <translation>Niedojrzały</translation>
    </message>
    <message>
        <source>Balances</source>
        <translation>Saldo</translation>
    </message>
    <message>
        <source>Total:</source>
        <translation>W sumie:</translation>
    </message>
    <message>
        <source>Your current total balance</source>
        <translation>Twoje obecne saldo:</translation>
    </message>
    <message>
        <source>Spendable:</source>
        <translation>Dostępne:</translation>
    </message>
    <message>
        <source>Recent transactions</source>
        <translation>Ostatnie transakcje</translation>
    </message>
    </context>
<context>
    <name>PaymentServer</name>
    <message>
        <source>Payment request error</source>
        <translation>Błąd żądania płatności</translation>
    </message>
    <message>
        <source>URI handling</source>
        <translation>Obsługa URI</translation>
    </message>
    <message>
        <source>Payment request fetch URL is invalid: %1</source>
        <translation>adres URL żądania zapłaty jest nieprawidłowy: %1</translation>
    </message>
    <message>
        <source>Invalid payment address %1</source>
        <translation>Nieprawidłowy adres płatności %1</translation>
    </message>
    <message>
        <source>Payment request rejected</source>
        <translation>Żądanie płatności odrzucone.</translation>
    </message>
    <message>
        <source>Payment request expired.</source>
        <translation>Żądanie płatności wygasło.</translation>
    </message>
    <message>
        <source>Payment request is not initialized.</source>
        <translation>Żądanie płatności nie zostało rozpoczęte.</translation>
    </message>
    <message>
        <source>Invalid payment request.</source>
        <translation>Nieprawidłowe żądanie płatności.</translation>
    </message>
    </context>
<context>
    <name>PeerTableModel</name>
    <message>
        <source>User Agent</source>
        <translation>Agent użytkownika</translation>
    </message>
    <message>
        <source>Sent</source>
        <translation>Wysłane</translation>
    </message>
    <message>
        <source>Received</source>
        <translation>Otrzymane</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Amount</source>
        <translation>Ilość</translation>
    </message>
    <message>
        <source>N/A</source>
        <translation>N/A</translation>
    </message>
    <message>
        <source>unknown</source>
        <translation>nieznany</translation>
    </message>
</context>
<context>
    <name>QObject::QObject</name>
    </context>
<context>
    <name>QRImageWidget</name>
    <message>
        <source>&amp;Save Image...</source>
        <translation>&amp;Zapisz obraz...</translation>
    </message>
    </context>
<context>
    <name>RPCConsole</name>
    <message>
        <source>N/A</source>
        <translation>N/A</translation>
    </message>
    <message>
        <source>Client version</source>
        <translation>Wersja klienta</translation>
    </message>
    <message>
        <source>&amp;Information</source>
        <translation>&amp;Informacje</translation>
    </message>
    <message>
        <source>Debug window</source>
        <translation>Debuguj okno</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Ogólny</translation>
    </message>
    <message>
        <source>Using BerkeleyDB version</source>
        <translation>Używasz BerkeleyDB wersji</translation>
    </message>
    <message>
        <source>Datadir</source>
        <translation>Datadir</translation>
    </message>
    <message>
        <source>Startup time</source>
        <translation>Czas rozpoczęcia</translation>
    </message>
    <message>
        <source>Network</source>
        <translation>Sieć</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Nazwa</translation>
    </message>
    <message>
        <source>Number of connections</source>
        <translation>Liczba połączeń</translation>
    </message>
    <message>
        <source>Block chain</source>
        <translation>Łańcuch bloku</translation>
    </message>
    <message>
        <source>Current number of blocks</source>
        <translation>Obecna liczba bloków</translation>
    </message>
    <message>
        <source>Memory Pool</source>
        <translation>Pula pamięci</translation>
    </message>
    <message>
        <source>Current number of transactions</source>
        <translation>Obecna liczba transakcji</translation>
    </message>
    <message>
        <source>Memory usage</source>
        <translation>Użycie pamięci</translation>
    </message>
    <message>
        <source>&amp;Reset</source>
        <translation>&amp;Reset</translation>
    </message>
    <message>
        <source>Received</source>
        <translation>Otrzymane</translation>
    </message>
    <message>
        <source>Sent</source>
        <translation>Wysłane</translation>
    </message>
    <message>
        <source>&amp;Peers</source>
        <translation>&amp;członkowie</translation>
    </message>
    <message>
        <source>Banned peers</source>
        <translation>Zablokowani członkowie</translation>
    </message>
    <message>
        <source>Select a peer to view detailed information.</source>
        <translation>Wybierz użytkownika by zobaczyć wiecej informacji</translation>
    </message>
    <message>
        <source>Whitelisted</source>
        <translation>Dopuszczeni</translation>
    </message>
    <message>
        <source>Direction</source>
        <translation>Kierunek</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>Wersja</translation>
    </message>
    <message>
        <source>Starting Block</source>
        <translation>Start bloku</translation>
    </message>
    <message>
        <source>Synced Headers</source>
        <translation>Nagłówki</translation>
    </message>
    <message>
        <source>Synced Blocks</source>
        <translation>Synchronizowane bloki</translation>
    </message>
    <message>
        <source>User Agent</source>
        <translation>Agent użytkownika</translation>
    </message>
    <message>
        <source>Decrease font size</source>
        <translation>zmniejsz rozmiar fonta</translation>
    </message>
    <message>
        <source>Increase font size</source>
        <translation>zwiększ rozmiar fonta</translation>
    </message>
    <message>
        <source>Services</source>
        <translation>Usługi</translation>
    </message>
    <message>
        <source>Ban Score</source>
        <translation>Liczba blokad</translation>
    </message>
    <message>
        <source>Connection Time</source>
        <translation>Czas połączenia</translation>
    </message>
    <message>
        <source>Last Send</source>
        <translation>Ostatnio wysłane</translation>
    </message>
    <message>
        <source>Last Receive</source>
        <translation>Ostatnio otrzymane</translation>
    </message>
    <message>
        <source>Ping Time</source>
        <translation>Czas pinga</translation>
    </message>
    <message>
        <source>Ping Wait</source>
        <translation>Oczekiwanie pinga</translation>
    </message>
    <message>
        <source>Min Ping</source>
        <translation>Min ping</translation>
    </message>
    <message>
        <source>Last block time</source>
        <translation>Czas ostatniego bloku...</translation>
    </message>
    <message>
        <source>&amp;Open</source>
        <translation>&amp;otwarte</translation>
    </message>
    <message>
        <source>&amp;Console</source>
        <translation>&amp;konsola</translation>
    </message>
    <message>
        <source>&amp;Network Traffic</source>
        <translation>&amp;traffic sieci</translation>
    </message>
    <message>
        <source>Totals</source>
        <translation>W sumie</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation>Tak</translation>
    </message>
    <message>
        <source>No</source>
        <translation>Nie</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Nieznane</translation>
    </message>
</context>
<context>
    <name>ReceiveCoinsDialog</name>
    <message>
        <source>&amp;Amount:</source>
        <translation>&amp;Ilość</translation>
    </message>
    <message>
        <source>&amp;Label:</source>
        <translation>&amp;Etykieta</translation>
    </message>
    <message>
        <source>&amp;Message:</source>
        <translation>&amp;Wiadomość</translation>
    </message>
    <message>
        <source>Clear all fields of the form.</source>
        <translation>Wyczyść wszystkie pola formularza.</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation>Wyczyść</translation>
    </message>
    <message>
        <source>Requested payments history</source>
        <translation>Historia żądań płatności.</translation>
    </message>
    <message>
        <source>&amp;Request payment</source>
        <translation>&amp;Zażądaj płatności</translation>
    </message>
    <message>
        <source>Show</source>
        <translation>Pokaż</translation>
    </message>
    <message>
        <source>Remove the selected entries from the list</source>
        <translation>Wykasuj z listy zaznaczone wejścia.</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Usuń</translation>
    </message>
    <message>
        <source>Copy URI</source>
        <translation>Kopiuj URI</translation>
    </message>
    <message>
        <source>Copy label</source>
        <translation>Kopiuj etykietę</translation>
    </message>
    <message>
        <source>Copy message</source>
        <translation>Kopiuj wiadomość</translation>
    </message>
    <message>
        <source>Copy amount</source>
        <translation>Kopiuj ilość</translation>
    </message>
</context>
<context>
    <name>ReceiveRequestDialog</name>
    <message>
        <source>QR Code</source>
        <translation>Kod QR</translation>
    </message>
    <message>
        <source>Copy &amp;URI</source>
        <translation>Kopiuj &amp;URl</translation>
    </message>
    <message>
        <source>Copy &amp;Address</source>
        <translation>Kopiuj &amp;Adres</translation>
    </message>
    <message>
        <source>&amp;Save Image...</source>
        <translation>&amp;Zapisz obraz...</translation>
    </message>
    <message>
        <source>Request payment to %1</source>
        <translation>Zażądaj płatności do %1</translation>
    </message>
    <message>
        <source>Payment information</source>
        <translation>Informacje o płatności</translation>
    </message>
    <message>
        <source>URI</source>
        <translation>URI</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Adres</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>Ilość</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>Etykieta</translation>
    </message>
    <message>
        <source>Message</source>
        <translation>Wiadomość</translation>
    </message>
    <message>
        <source>Wallet</source>
        <translation>Portfel</translation>
    </message>
    <message>
        <source>Error encoding URI into QR Code.</source>
        <translation>Błąd podczas zmiany URI w QR kod.</translation>
    </message>
</context>
<context>
    <name>RecentRequestsTableModel</name>
    <message>
        <source>Date</source>
        <translation>Data</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>Etykieta</translation>
    </message>
    <message>
        <source>Message</source>
        <translation>Wiadomość</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(bez etykiety)</translation>
    </message>
    <message>
        <source>(no message)</source>
        <translation>(brak wiadomości)</translation>
    </message>
    <message>
        <source>(no amount requested)</source>
        <translation>(bez ilości)</translation>
    </message>
    <message>
        <source>Requested</source>
        <translation>Żądane</translation>
    </message>
</context>
<context>
    <name>SendCoinsDialog</name>
    <message>
        <source>Send Coins</source>
        <translation>Wyślij moniaki</translation>
    </message>
    <message>
        <source>Coin Control Features</source>
        <translation>Funkcje kontroli moniaków</translation>
    </message>
    <message>
        <source>Inputs...</source>
        <translation>Wejścia...</translation>
    </message>
    <message>
        <source>automatically selected</source>
        <translation>Automatycznie wybrane</translation>
    </message>
    <message>
        <source>Insufficient funds!</source>
        <translation>Za mało środków</translation>
    </message>
    <message>
        <source>Quantity:</source>
        <translation>Ilość:</translation>
    </message>
    <message>
        <source>Bytes:</source>
        <translation>Bajtów:</translation>
    </message>
    <message>
        <source>Amount:</source>
        <translation>Ilość:</translation>
    </message>
    <message>
        <source>Fee:</source>
        <translation>Opłata:</translation>
    </message>
    <message>
        <source>After Fee:</source>
        <translation>Po odliczeniu opłaty:</translation>
    </message>
    <message>
        <source>Change:</source>
        <translation>Zmiana:</translation>
    </message>
    <message>
        <source>Transaction Fee:</source>
        <translation>Koszt transakcji:</translation>
    </message>
    <message>
        <source>Choose...</source>
        <translation>Wybierz...</translation>
    </message>
    <message>
        <source>Warning: Fee estimation is currently not possible.</source>
        <translation>Ostrzeżenie: obecnie brak możliwości estymacji kosztu.</translation>
    </message>
    <message>
        <source>collapse fee-settings</source>
        <translation>Załamanie ustawienia kosztu</translation>
    </message>
    <message>
        <source>per kilobyte</source>
        <translation>na kilobajt.</translation>
    </message>
    <message>
        <source>Hide</source>
        <translation>Ukryj</translation>
    </message>
    <message>
        <source>Recommended:</source>
        <translation>Rekomendowany</translation>
    </message>
    <message>
        <source>Custom:</source>
        <translation>Zwyczaj:</translation>
    </message>
    <message>
        <source>(Smart fee not initialized yet. This usually takes a few blocks...)</source>
        <translation>(Smart koszt nie został zainicjowany. Zwykle trwa to kilka bloków...)</translation>
    </message>
    <message>
        <source>Send to multiple recipients at once</source>
        <translation>Wyślij do wielu odbiorców naraz</translation>
    </message>
    <message>
        <source>Add &amp;Recipient</source>
        <translation>Dodaj &amp;Odbiorcę</translation>
    </message>
    <message>
        <source>Clear all fields of the form.</source>
        <translation>Wyczyść wszystkie pola formularza.</translation>
    </message>
    <message>
        <source>Clear &amp;All</source>
        <translation>Wyczyść &amp;wszystko</translation>
    </message>
    <message>
        <source>Balance:</source>
        <translation>Saldo:</translation>
    </message>
    <message>
        <source>Confirm the send action</source>
        <translation>Potwierdź wysyłkę</translation>
    </message>
    <message>
        <source>S&amp;end</source>
        <translation>W&amp;yślij</translation>
    </message>
    <message>
        <source>Copy quantity</source>
        <translation>Kopiuj ilość</translation>
    </message>
    <message>
        <source>Copy amount</source>
        <translation>Kopiuj ilość</translation>
    </message>
    <message>
        <source>Copy fee</source>
        <translation>Kopiuj koszt</translation>
    </message>
    <message>
        <source>Copy after fee</source>
        <translation>Kopiuj po opłacie</translation>
    </message>
    <message>
        <source>Copy bytes</source>
        <translation>Kopiuj bajty</translation>
    </message>
    <message>
        <source>Copy dust</source>
        <translation>Kopiuj pył</translation>
    </message>
    <message>
        <source>Copy change</source>
        <translation>Kopiuj zmianę</translation>
    </message>
    <message>
        <source>Are you sure you want to send?</source>
        <translation>Czy na pewno jesteś pewien że chcesz wysłać?</translation>
    </message>
    <message>
        <source>or</source>
        <translation>lub</translation>
    </message>
    <message>
        <source>Confirm send coins</source>
        <translation>Potwierdź wysyłkę moniaków</translation>
    </message>
    <message>
        <source>The recipient address is not valid. Please recheck.</source>
        <translation>Adres odbiorcy jest nieprawidłowy. Sprawdź ponownie.</translation>
    </message>
    <message>
        <source>The amount to pay must be larger than 0.</source>
        <translation>Wartość do zapłaty musi być większa od 0.</translation>
    </message>
    <message>
        <source>The amount exceeds your balance.</source>
        <translation>Wartość przekracza Twoje saldo.</translation>
    </message>
    <message>
        <source>The total exceeds your balance when the %1 transaction fee is included.</source>
        <translation>Wliczając opłatę za transakcję %1, Twoje saldo zostałoby przekroczone.</translation>
    </message>
    <message>
        <source>Duplicate address found: addresses should only be used once each.</source>
        <translation>Znaleziono zduplikowany adres. Adresy powinny być użyte jednokrotnie.</translation>
    </message>
    <message>
        <source>Transaction creation failed!</source>
        <translation>Utworzenie transakcji nie doszło do skutku.</translation>
    </message>
    <message>
        <source>Payment request expired.</source>
        <translation>Żądanie płatności wygasło.</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(bez etykiety)</translation>
    </message>
</context>
<context>
    <name>SendCoinsEntry</name>
    <message>
        <source>&amp;Label:</source>
        <translation>&amp;Etykieta</translation>
    </message>
    <message>
        <source>Alt+A</source>
        <translation>Alt+A</translation>
    </message>
    <message>
        <source>Alt+P</source>
        <translation>Alt+P</translation>
    </message>
    <message>
        <source>Message:</source>
        <translation>Wiadomość:</translation>
    </message>
    </context>
<context>
    <name>SendConfirmationDialog</name>
    <message>
        <source>Yes</source>
        <translation>Tak</translation>
    </message>
</context>
<context>
    <name>ShutdownWindow</name>
    </context>
<context>
    <name>SignVerifyMessageDialog</name>
    <message>
        <source>Alt+A</source>
        <translation>Alt+A</translation>
    </message>
    <message>
        <source>Alt+P</source>
        <translation>Alt+P</translation>
    </message>
    <message>
        <source>Signature</source>
        <translation>Sygnatura</translation>
    </message>
    <message>
        <source>Clear &amp;All</source>
        <translation>Wyczyść &amp;wszystko</translation>
    </message>
    <message>
        <source>The entered address is invalid.</source>
        <translation>Wprowadzony adres jest nieprawidłowy.</translation>
    </message>
    </context>
<context>
    <name>SplashScreen</name>
    <message>
        <source>[testnet]</source>
        <translation>[testnet]</translation>
    </message>
</context>
<context>
    <name>TrafficGraphWidget</name>
    <message>
        <source>KB/s</source>
        <translation>KB/s</translation>
    </message>
</context>
<context>
    <name>TransactionDesc</name>
    <message>
        <source>Status</source>
        <translation>Status</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Data</translation>
    </message>
    <message>
        <source>Source</source>
        <translation>Źródło</translation>
    </message>
    <message>
        <source>From</source>
        <translation>Od</translation>
    </message>
    <message>
        <source>unknown</source>
        <translation>nieznany</translation>
    </message>
    <message>
        <source>To</source>
        <translation>Do</translation>
    </message>
    <message>
        <source>own address</source>
        <translation>własny adres</translation>
    </message>
    <message>
        <source>label</source>
        <translation>etykieta</translation>
    </message>
    <message>
        <source>Message</source>
        <translation>Wiadomość</translation>
    </message>
    <message>
        <source>Comment</source>
        <translation>Komentarz</translation>
    </message>
    <message>
        <source>Transaction</source>
        <translation>Tranzakcja</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>Ilość</translation>
    </message>
    <message>
        <source>true</source>
        <translation>prawda</translation>
    </message>
    <message>
        <source>false</source>
        <translation>fałsz</translation>
    </message>
</context>
<context>
    <name>TransactionDescDialog</name>
    </context>
<context>
    <name>TransactionTableModel</name>
    <message>
        <source>Date</source>
        <translation>Data</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Typ</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>Etykieta</translation>
    </message>
    <message>
        <source>Received from</source>
        <translation>Otrzymane on</translation>
    </message>
    <message>
        <source>Sent to</source>
        <translation>Wyślij do</translation>
    </message>
    <message>
        <source>(n/a)</source>
        <translation>(n/a)</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(bez etykiety)</translation>
    </message>
    </context>
<context>
    <name>TransactionView</name>
    <message>
        <source>Sent to</source>
        <translation>Wyślij do</translation>
    </message>
    <message>
        <source>Copy address</source>
        <translation>Kopiuj adres</translation>
    </message>
    <message>
        <source>Copy label</source>
        <translation>Kopiuj etykietę</translation>
    </message>
    <message>
        <source>Copy amount</source>
        <translation>Kopiuj ilość</translation>
    </message>
    <message>
        <source>Comma separated file (*.csv)</source>
        <translation>Plik oddzielony przecinkiem (*.csv)</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Data</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Typ</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>Etykieta</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Adres</translation>
    </message>
    <message>
        <source>Exporting Failed</source>
        <translation>Eksport nie powiódł się</translation>
    </message>
    </context>
<context>
    <name>UnitDisplayStatusBarControl</name>
    </context>
<context>
    <name>WalletController</name>
    </context>
<context>
    <name>WalletFrame</name>
    </context>
<context>
    <name>WalletModel</name>
    <message>
        <source>Send Coins</source>
        <translation>Wyślij coiny</translation>
    </message>
    </context>
<context>
    <name>WalletView</name>
    <message>
        <source>&amp;Export</source>
        <translation>&amp;Eksportuj</translation>
    </message>
    <message>
        <source>Export the data in the current tab to a file</source>
        <translation>Eksportuj dane z aktywnej karty do pliku</translation>
    </message>
    </context>
<context>
    <name>bitcoin-core</name>
    <message>
        <source>Loading banlist...</source>
        <translation>Ładuję banlistę...</translation>
    </message>
    <message>
        <source>Information</source>
        <translation>Informacja</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>Ostrzeżenie</translation>
    </message>
    <message>
        <source>Insufficient funds</source>
        <translation>Za mało środków</translation>
    </message>
    <message>
        <source>Loading block index...</source>
        <translation>Ładuję listę bloków</translation>
    </message>
    <message>
        <source>Loading wallet...</source>
        <translation>Ładuję portfel...</translation>
    </message>
    <message>
        <source>Cannot downgrade wallet</source>
        <translation>Nie można zmniejszyć portfela</translation>
    </message>
    <message>
        <source>Rescanning...</source>
        <translation>Ponowne skanowanie...</translation>
    </message>
    <message>
        <source>Done loading</source>
        <translation>Zakończono ładowanie</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Błąd</translation>
    </message>
</context>
</TS>